"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.userData = exports.store = void 0;
const electron_1 = require("electron");
const fs_1 = require("fs");
const os_1 = require("os");
const path_1 = require("path");
class JSONStore {
    settingsFile;
    data;
    constructor() {
        const settingsDir = (0, path_1.join)((0, os_1.homedir)(), ".phasereditor2d/all-in-one");
        (0, fs_1.mkdirSync)(settingsDir, { recursive: true });
        this.settingsFile = (0, path_1.join)(settingsDir, "user-data.json");
        this.data = {};
        if ((0, fs_1.existsSync)(this.settingsFile)) {
            const s = (0, fs_1.readFileSync)(this.settingsFile, {
                encoding: "utf-8"
            });
            try {
                this.data = JSON.parse(s.toString());
            }
            catch (e) {
                console.log(e);
                setTimeout(() => {
                    electron_1.dialog.showErrorBox("Error", "Error parsing user-data.json: " + e.message);
                }, 2000);
            }
        }
    }
    getValue(key) {
        return this.data[key];
    }
    getString(key) {
        return this.data[key];
    }
    getInt(key) {
        const value = this.data[key];
        if (Number.isInteger(value)) {
            return value;
        }
        return undefined;
    }
    getStringArray(key) {
        let val = this.data[key];
        if (!val) {
            this.data[key] = val = [];
        }
        return val;
    }
    setValue(key, value) {
        this.data[key] = value;
        this.save();
    }
    deleteValue(key) {
        delete this.data[key];
        this.save();
    }
    save() {
        (0, fs_1.writeFileSync)(this.settingsFile, JSON.stringify(this.data, null, 4), {
            encoding: "utf-8"
        });
    }
}
exports.store = new JSONStore();
class UserData {
    getProjectPath() {
        return exports.store.getString("projectPath");
    }
    setProjectPath(project) {
        exports.store.setValue("projectPath", project);
    }
    deleteProjectPath() {
        exports.store.deleteValue("projectPath");
    }
    getProjectPort(project) {
        const ports = exports.store.getValue("ports") || {};
        return ports[project];
    }
    setProjectPort(project, port) {
        const ports = exports.store.getValue("ports") || {};
        ports[project] = port;
        exports.store.setValue("ports", ports);
    }
    getRecentProjects() {
        const recentProjects = exports.store.getValue("recentProjects") || {};
        const projects = Object.keys(recentProjects);
        projects.sort((a, b) => recentProjects[b] - recentProjects[a]);
        return projects;
    }
    clearRecentProjects() {
        exports.store.setValue("recentProjects", {});
    }
    incrementRecentProject(project) {
        const recentProjects = exports.store.getValue("recentProjects") || {};
        recentProjects[project] = Date.now();
        exports.store.setValue("recentProjects", recentProjects);
    }
    deleteRecentProject(project) {
        const data = (exports.store.getValue("recentProjects") || {});
        delete data[project];
        exports.store.setValue("recentProjects", data);
    }
}
exports.userData = new UserData();
